@@ -1,7 +1,8 @@
 init2.jk.j <-
-function(reference,response,L,K,tsplit,model,msplit,previousz,previousclust, previous.alpha, previous.beta){
+function(reference,response,L,K,tsplit,model,msplit,previousz,previousclust, previous.alpha, previous.beta,mnr){
 x = reference
 y = response
+maxnr = mnr
 n1<-dim(y)[1]
 n2<-dim(x)[1]
 if (n1 != n2) stop("number of observations does not coincide for x and y")
@@ -161,7 +162,8 @@ for(j in 1:q){
 #st[1]<-alpha[iter,j,k]
 #st[2:(tau+1)]<-beta[iter,j,k,]
 
-nrthreshold <- log(10^(-10));maxnr = 10
+nrthreshold <- log(10^(-10));
+#maxnr = 10
 sc <- nrthreshold + 1
 #theta<- runif(1+tau)
 #sumy<-rowSums(array(y[,index[j]:(index[j]-1+L[j])],dim=c(n,1)))
@@ -315,7 +317,8 @@ for(j in 1:q){
 #st[2:(tau+1)]<-beta[iter,j,k,]
 #run<-glm(yy[,j]~x,family=poisson, start = st, weights = z[,k])
 
-nrthreshold <- log(10^(-10));maxnr = 3
+nrthreshold <- log(10^(-10)); 
+#maxnr = 3
 sc <- nrthreshold + 1
 theta[1] <- alpha[iter,j,k]# alpha[j,]'s
 theta[2:(tau+1)] <- beta[iter, j,k,]# beta_{j}
@@ -499,7 +502,8 @@ z[z<epsilon]<-rep(epsilon,sl)
 z[z>1-epsilon]<-rep(1-epsilon,bl)
 z<-z/rowSums(z)
 
-nrthreshold <- log(10^(-10));maxnr = 3
+nrthreshold <- log(10^(-10));
+#maxnr = 3
 
 #######################################################################################################################
 #######################################################################################################################
@@ -526,7 +530,7 @@ theta[(K+3):(K+2+tau)] <- beta[iter, j,]# beta_{j}
 theta1<-theta
 #iter1<-0
 # Main Loop of N-R iterations
-maxnr=10
+#maxnr=10
 metritis = 1
 while (sc > nrthreshold&metritis<maxnr ) {
 metritis = metritis + 1
@@ -673,7 +677,7 @@ theta[(K+3):(K+2+tau)] <- beta[iter, j,]# beta_{j}
 theta1<-theta
 #iter1<-0
 # Main Loop of N-R iterations
-maxnr=10
+#maxnr=10
 metritis = 1
 while (sc > nrthreshold&metritis<maxnr ) {
 metritis = metritis + 1
